==> dpcmaps-1.1.2.tar.gz: dpcmaps-1.1.2/setup.py <==
from os import path
from setuptools import setup, find_packages
import sys
import versioneer


# NOTE: This file must remain Python 2 compatible for the foreseeable future,
# to ensure that we error out properly for people with outdated setuptools
# and/or pip.
min_version = (3, 7)
if sys.version_info < min_version:
    error = """
dpcmaps does not support Python {0}.{1}.
Python {2}.{3} and above is required. Check your Python version like so:

python3 --version

This may be due to an out-of-date pip. Make sure you have pip >= 9.0.1.
Upgrade pip like so:

pip install --upgrade pip
""".format(
        *(sys.version_info[:2] + min_version)
    )
    sys.exit(error)

here = path.abspath(path.dirname(__file__))

with open(path.join(here, "README.rst"), encoding="utf-8") as readme_file:
    readme = readme_file.read()

with open(path.join(here, "requirements.txt")) as requirements_file:
    # Parse requirements.txt, ignoring any commented-out lines.
    requirements = [line for line in requirements_file.read().splitlines() if not line.startswith("#")]


setup(
    name="dpcmaps",
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    description="Software for generating and analysis of DPC Maps",
    long_description=readme,
    author="Brookhaven National Laboratory",
    author_email="",
    url="https://github.com//dpcmaps",
    python_requires=">={}".format(".".join(str(n) for n in min_version)),
    packages=find_packages(exclude=["docs", "tests"]),
    entry_points={
        "console_scripts": ["dpcmaps = dpcmaps.dpc_gui:run_dpc_gui"],
    },
    include_package_data=True,
    package_data={
        # When adding files here, remember to update MANIFEST.in as well,
        # or else they will not be included in the distribution on PyPI!
        # 'path/to/data_file',
        "dpcmaps.cmap_previews": ["*.png"]
    },
    install_requires=requirements,
    license="BSD (3-clause)",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
    ],
)

==> dpcmaps-1.1.3.tar.gz: dpcmaps-1.1.3/setup.py <==
from os import path
from setuptools import setup, find_packages
import sys
import versioneer


# NOTE: This file must remain Python 2 compatible for the foreseeable future,
# to ensure that we error out properly for people with outdated setuptools
# and/or pip.
min_version = (3, 7)
if sys.version_info < min_version:
    error = """
dpcmaps does not support Python {0}.{1}.
Python {2}.{3} and above is required. Check your Python version like so:

python3 --version

This may be due to an out-of-date pip. Make sure you have pip >= 9.0.1.
Upgrade pip like so:

pip install --upgrade pip
""".format(
        *(sys.version_info[:2] + min_version)
    )
    sys.exit(error)

here = path.abspath(path.dirname(__file__))

with open(path.join(here, "README.rst"), encoding="utf-8") as readme_file:
    readme = readme_file.read()

with open(path.join(here, "requirements.txt")) as requirements_file:
    # Parse requirements.txt, ignoring any commented-out lines.
    requirements = [line for line in requirements_file.read().splitlines() if not line.startswith("#")]


setup(
    name="dpcmaps",
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    description="Software for generating and analysis of DPC Maps",
    long_description=readme,
    author="Brookhaven National Laboratory",
    author_email="",
    url="https://github.com/NSLS-II/dpcmaps",
    python_requires=">={}".format(".".join(str(n) for n in min_version)),
    packages=find_packages(exclude=["docs", "tests"]),
    entry_points={
        "console_scripts": [
            "dpcmaps = dpcmaps.dpc_gui:run_dpc_gui",
            "dpcmaps-batch = dpcmaps.dpc_batch_gui:run_dpc_batch_gui",
            "dpcmaps-script = dpcmaps.dpc_batch:run_dpc_script",
        ],
    },
    include_package_data=True,
    package_data={
        # When adding files here, remember to update MANIFEST.in as well,
        # or else they will not be included in the distribution on PyPI!
        # 'path/to/data_file',
        "dpcmaps.cmap_previews": ["*.png"]
    },
    install_requires=requirements,
    license="BSD (3-clause)",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
    ],
)
